@@ -1,6 +1,7 @@
 from webdriverplus.orderedset import OrderedSet
 from webdriverplus.selectors import SelectorMixin
 from webdriverplus.wrappers import Style, Attributes
+from webdriverplus.deprecation import deprecated_property
 
 
 class WebElementSet(SelectorMixin, OrderedSet):
@@ -44,6 +45,22 @@ class WebElementSet(SelectorMixin, OrderedSet):
     def text(self):
         return self._first.text
 
+    @deprecated_property
+    def is_selected(self):
+        return self._first.is_selected()
+
+    @deprecated_property
+    def is_enabled(self):
+        return self._first.is_enabled()
+
+    @deprecated_property
+    def is_displayed(self):
+        return self._first.is_displayed()
+
+    @deprecated_property
+    def is_checked(self):
+        return self._first.is_checked()
+
     # Events...
     def click(self):
         self._first.click()
@@ -65,8 +82,12 @@ class WebElementSet(SelectorMixin, OrderedSet):
         self._first.release()
         return self
 
-    def move_to(self):
-        self._first.move_to()
+    def move_to(self, x=0, y=0):
+        self._first.move_to(x, y)
+        return self
+
+    def move_to_and_click(self, *args, **kwargs):
+        self._first.move_to_and_click(*args, **kwargs)
         return self
 
     def check(self):
@@ -89,21 +110,8 @@ class WebElementSet(SelectorMixin, OrderedSet):
     def get_attribute(self, name):
         return self._first.get_attribute(name)
 
-    @property
-    def is_selected(self):
-        return self._first.is_selected
-
-    @property
-    def is_enabled(self):
-        return self._first.is_enabled
-
-    @property
-    def is_displayed(self):
-        return self._first.is_displayed
-
-    @property
-    def is_checked(self):
-        return self._first.is_checked
+    def attr(self, name):
+        return self._first.attr(name)
 
     def send_keys(self, *value):
         [elem.send_keys(*value) for elem in self]
@@ -152,6 +160,15 @@ class WebElementSet(SelectorMixin, OrderedSet):
     def attributes(self):
         return Attributes(self._first)
 
+    def has_class(self, cls):
+        for elem in self:
+            if elem.has_class(cls):
+                return True
+        return False
+
+    def css(self, name, value=None):
+        return self._first.css(name, value)
+
     def javascript(self, script):
         return [elem.javascript(script) for elem in self]
 
@@ -221,6 +238,15 @@ class WebElementSet(SelectorMixin, OrderedSet):
             ret |= elem.siblings()
         return ret.filter(*args, **kwargs)
 
+    def type_keys(self, *args):
+        return self._first.type_keys(*args)
+
+    def select_option(self, value=None, text=None, index=None):
+        return self._first.select_option(value=value, text=text, index=index)
+
+    def deselect_option(self, value=None, text=None, index=None):
+        return self._first.deselect_option(value=value, text=text, index=index)
+
     def __getitem__(self, key):
         if isinstance(key, slice):
             elems = list(self)[key]
